@@ -1,9 +1,10 @@
 from kof_api.Ship import Ship
 
+
 class Sloop(Ship):
 	def __init__(self):
 		self.name = "Sloop"
-		self.type = 'civilian'
+		self.type = ['civilian', 'ship']
 		self.desc = ""
 		self.max_capacity = 300
 		self.max_crew = 25
